@@ -31,7 +31,7 @@ resampling_task_hashes = function(task, resampling, learner = NULL) {
 task_hash = function(task, use_ids, test_ids = NULL, ignore_internal_valid_task = FALSE) {
   # order matters: we first check for test_ids and then for the internal_valid_task
   internal_valid_task_hash = if (!is.null(test_ids)) {
-    # this does the same as 
+    # this does the same as
     # task$internal_valid_task = test_ids
     # $internal_valid_task$hash
     # but avoids the deep clone
@@ -40,6 +40,14 @@ task_hash = function(task, use_ids, test_ids = NULL, ignore_internal_valid_task
     task$internal_valid_task$hash
   }
 
-  calculate_hash(class(task), task$id, task$backend$hash, task$col_info, use_ids, task$col_roles,
-    get_private(task)$.properties, internal_valid_task_hash)
+  calculate_hash(
+    class(task),
+    task$id,
+    task$backend$hash,
+    task$col_info,
+    use_ids,
+    task$col_roles,
+    get_private(task)$.properties,
+    internal_valid_task_hash,
+    task$characteristics)
 }
